summaryrefslogtreecommitdiffstats
path: root/routers/install/setting.go
diff options
context:
space:
mode:
Diffstat (limited to 'routers/install/setting.go')
-rw-r--r--routers/install/setting.go12
1 files changed, 6 insertions, 6 deletions
diff --git a/routers/install/setting.go b/routers/install/setting.go
index e2af66cfb4..cf0a01ce31 100644
--- a/routers/install/setting.go
+++ b/routers/install/setting.go
@@ -16,17 +16,17 @@ import (
// PreloadSettings preloads the configuration to check if we need to run install
func PreloadSettings(ctx context.Context) bool {
- setting.NewContext()
+ setting.LoadAllowEmpty()
if !setting.InstallLock {
log.Info("AppPath: %s", setting.AppPath)
log.Info("AppWorkPath: %s", setting.AppWorkPath)
log.Info("Custom path: %s", setting.CustomPath)
log.Info("Log path: %s", setting.LogRootPath)
log.Info("Configuration file: %s", setting.CustomConf)
- log.Info("Preparing to run install page")
+ log.Info("Prepare to run install page")
translation.InitLocales()
if setting.EnableSQLite3 {
- log.Info("SQLite3 Supported")
+ log.Info("SQLite3 is supported")
}
setting.InitDBConfig()
setting.NewServicesForInstall()
@@ -36,9 +36,9 @@ func PreloadSettings(ctx context.Context) bool {
return !setting.InstallLock
}
-// ReloadSettings rereads the settings and starts up the database
-func ReloadSettings(ctx context.Context) {
- setting.NewContext()
+// reloadSettings reloads the existing settings and starts up the database
+func reloadSettings(ctx context.Context) {
+ setting.LoadFromExisting()
setting.InitDBConfig()
if setting.InstallLock {
if err := common.InitDBEngine(ctx); err == nil {